@@ -12,6 +12,7 @@ from pandas import DataFrame
 from bisect import insort_left
 import matplotlib.pyplot as plt
 from pmpy.dist import distribution
+from matplotlib import animation, lines
 import pmpy.des as des
 
 
@@ -43,7 +44,7 @@ class agent_type():
         return xlist,ylist
         
         
-class agent(des.entity):
+class agent(des.environment.process):
     """
     A class that defines an Agents. Agents are virtual objects essential to useful for modeling dynamic systems. 
     Some examples of Agents can be: a customer, communication message, or any resource requiring service.
@@ -88,7 +89,8 @@ class agent(des.entity):
         """
         super().__init__(env,type.name,print_actions,log)
         
-       
+        self.env=env
+        self.name=type.name
         self.x=location[0]
         self.y=location[1]
         self.agent_type=type
@@ -869,7 +871,7 @@ class environment(des.environment):
     agents:list
         list of all agents created in the environment
     """
-    def __init__(self,width:int,hight:int):
+    def __init__(self,xrange=(0,100),yrange=(0,100)):
         """
         Creates an instance of the simulation environment
         width: int
@@ -879,10 +881,10 @@ class environment(des.environment):
 
         """
         super().__init__()
-        self.hight=hight
-        self.width=width
         self.fig = plt.figure()
-        self.ax = plt.axes(xlim=(0, width), ylim=(0, hight))
+        self.ax = plt.axes(xlim=xrange, ylim=yrange)
+   
+        self.lines=[]
         self.agents=[]
         self.agents_xloc={} #key is the name and value is list of x values of those agents
         self.agents_yloc={} #key is the name and value is list of y values of those agents
@@ -911,31 +913,27 @@ class environment(des.environment):
             Entities.append(agent(self,name,shape,location,print_actions,log))
         return Entities
 
+
+
     def run(self):
-        #super().__run(until)
-        # for agent_t in self.agents:
-        #     self.ax.plot(agent_t.x,agent_t.y,agent_t.shape,label=agent_t.name)
-    
-        # self.ax.legend()
-        # plt.show(block=True)
-        while True:
-            try:
-                super().step()
-            except:
-                break
+        for a in self.agents:
+            line, = self.ax.plot([], [],a.shape,label=a.name)
+            self.lines.append(line)
         
-        for agent_t in self.agents:
-            xlist,ylist=agent_t.xy_list()
-            self.ax.plot(xlist,ylist,agent_t.shape,label=agent_t.name)
-    
+        def animate(k:int):
+            self.step()
+            for i in range (len(self.agents)):
+                data=self.agents[i].xy_list()
+                self.lines[i].set_data(data[0],data[1])
+            return self.lines
+
+        self.anim = animation.FuncAnimation(self.fig, animate,
+                               frames=2000, interval=10, blit=True)
+
         self.ax.legend()
         plt.show(block=True)
 
-        def step(self):
-            super().step()
-            for i in range (self.agents):
-                data=self.agents[i].xy_list()
-                #agent_objects[i].setdata(data[0],data[1])
+        
         '''
 # initialization function: plot the background of each frame
 def init():
